==> haskell-yesod-test-1.6.4-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.4
id: yesod-test-1.6.4-I7ep8YPnbqI7EI5Pjhm02P
key: yesod-test-1.6.4-I7ep8YPnbqI7EI5Pjhm02P
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 5ff3efbd3ca2e3b1474283af8bac653f
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-test-1.6.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-test-1.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-test-1.6.4
hs-libraries: HSyesod-test-1.6.4-I7ep8YPnbqI7EI5Pjhm02P
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N
    html-conduit-1.3.1-EoJYDzXx8uR1xCF1vxzfM6
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
    persistent-2.8.2-AGG48nwB5kc4UaCabixjGv
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx
    wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on
    xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N=e0a953b556df722532d5f3ec3bd0085a
             html-conduit-1.3.1-EoJYDzXx8uR1xCF1vxzfM6=450076231038258b4fb1ef799f97d663
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             persistent-2.8.2-AGG48nwB5kc4UaCabixjGv=df9c6d9e5194ab13c9433376e4925c80
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=6113716a5efda4345adf3bac9f3dc9b0
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx=a10b0b451ac20f27f6160db52b013dec
             wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on=a72ffbe2bfa51351bf53d691c5b04e1a
             xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh=6d211c383cd1f227aab8bf60237f1a38
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2=1ea912c8bb8ceac914485e60e466bdfb
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.4-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.6.4
id: yesod-test-1.6.4-BjNAO1ZVWDRAZHqHkAEFmc
key: yesod-test-1.6.4-BjNAO1ZVWDRAZHqHkAEFmc
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author: Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
abi: 6d59cb38ecb8191c1bb07f0b8329eef3
exposed: True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-test-1.6.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-test-1.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-test-1.6.4
hs-libraries: HSyesod-test-1.6.4-BjNAO1ZVWDRAZHqHkAEFmc
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N
    html-conduit-1.3.1-BpVoUBjAFZ8C1oVlfWR1cM
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK
    persistent-2.8.2-2FoKOvco4h3699ygtEWdD3
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh
    wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV
    xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N=e0a953b556df722532d5f3ec3bd0085a
             html-conduit-1.3.1-BpVoUBjAFZ8C1oVlfWR1cM=4a6bf35accdc106ab8c5e6d2d43be658
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK=94d8930bfafd62e59b581d22ac71f05d
             persistent-2.8.2-2FoKOvco4h3699ygtEWdD3=ba56452b7de5f8cf1529c889461dbb80
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=6113716a5efda4345adf3bac9f3dc9b0
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh=3c531a9c9dceb5cf3884617d81bc336d
             wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV=b4aa7ea7b4308af6e795a2fe46a71976
             xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG=4b15a73ad6920f20ed76816962e99c5e
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo=804195ab12393543e6e312d52e756424
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
